module.exports = defineTest({
	description: 'imports default from external module',
	options: {
		external: ['path']
	}
});
